@@ -3,6 +3,7 @@ from prettytable import PrettyTable
 from .core import main
 
 import argparse
+import emoji
 
 default_nodes = [
     "https://hived.emre.sh",
@@ -29,7 +30,7 @@ def runner():
                         [f"[{i}]",
                          scan_result["node"],
                          sub_call,
-                         "✅" if scan_status else "❌",
+                         emoji.emojize(":check_mark_button:") if scan_status else emoji.emojize("cross mark"),
                          int(scan_result["time_spent"] * 1e4),
                          scan_result.get("error", "-")]
                     )
